.. currentmodule:: rayoptics.optical

*********************
Paraxial Design Model
*********************

Overview
========

   Paraxial layout operations are handled via the :class:`paraxialdesign.ParaxialModel`. This enables model manipulation via the :math:`y-\overline{y}` or :math:`\omega-\overline{\omega}` diagrams.

   Optical layout is facilitated by being able to use paraxial properties to solve for constructional parameters.
